#
# spec file for package bats
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pname %{name}-core
Name:           bats
Version:        1.5.0
Release:        bp154.1.22
Summary:        Bash Automated Testing System
License:        MIT
Group:          Development/Tools/Other
URL:            https://github.com/%{pname}/%{pname}/
Source:         https://github.com/%{pname}/%{pname}/archive/v%{version}.tar.gz#/%{pname}-%{version}.tar.gz
BuildRequires:  ncurses-utils
Requires:       gnu_parallel
BuildArch:      noarch

%description
Bats is a TAP-compliant (http://testanything.org/) testing framework for Bash.
It provides a simple and repeatable way to verify that the UNIX programs you
write behave as expected.

A Bats test file is a Bash script with special syntax for defining test cases.
Under the hood, each test case is just a function with a description.

Bats is most useful when testing software written in Bash, but you can use it
to test any UNIX program.

%prep
%setup -q -n %{pname}-%{version}

sed -i '1s|#!%{_bindir}/env bash|#!/bin/bash|' ./lib{,exec}/%{pname}/* ./bin/bats
%if 0%{?suse_version} <= 1500
    mv -v libexec/%{pname}/* lib/%{pname}/
    sed -i 's|libexec|lib|g' install.sh ./lib/%{pname}/* ./bin/bats ./test/*.bats
%endif

%build

%install
./install.sh %{buildroot}%{_prefix}

%check
./bin/bats test/bats.bats
./bin/bats test/suite.bats

%files
%license LICENSE.md
%doc README.md
%{_bindir}/bats
%{_prefix}/lib/%{pname}
%if 0%{?suse_version} > 1500
%{_libexecdir}/%{pname}
%endif
%{_mandir}/man1/bats.1%{?ext_man}
%{_mandir}/man7/bats.7%{?ext_man}

%changelog
* Sat Dec 11 2021 Olav Reinert <seroton10@gmail.com>
- boo#1193177: Fix build on Leap and SLE
* Wed Nov 24 2021 Dirk Müller <dmueller@suse.com>
- update to 1.5.0:
  * new command line flags
  * `--verbose-run`: Make `run` print `$output` by default
  * `-x`, `--trace`: Print test commands as they are executed (like `set -x`)`
  * `--show-output-of-passing-tests`: Print output of passing tests
  * `--print-output-on-failure`: Automatically print the value of  `$output` on
    failed tests
  * `--gather-test-outputs-in <directory>`: Gather the output of failing **and**
    passing tests as files in directory
  * Experimental: add return code checks to `run` via `!`/`-<N>`
  * `install.sh` and `uninstall.sh` take an optional second parameter for the lib
    folder name to allow for multilib install, e.g. into lib64
  * add `run` flag `--keep-empty-lines` to retain empty lines in `${lines[@]}`
  * add `run` flag `--separate-stderr` which also fills `$stderr` and
    `$stderr_lines`
  * don't glob `run`'s `$output` when splitting into `${lines[@]}`
  * remove empty line after test with pretty formatter on some terminals
  * don't run setup_file/teardown_file on files without tests, e.g. due to
    filtering
  * print final line without newline on Bash 3.2 for midtest (ERREXIT) failures
  * abort with error on missing flock/shlock when running in parallel mode
  * improved `set -u` test and fixed some unset variable accesses
  * shorten suite/file/test temporary folder paths to leave enough space even on
    restricted systems
  * added BATS_TEST_TMPDIR, BATS_FILE_TMPDIR, BATS_SUITE_TMPDIR
  * added checks and improved documentation for `$BATS_TMPDIR`
  * the docker container now uses [tini](https://github.com/krallin/tini) as the
    container entrypoint to improve signal forwarding
  * script to uninstall bats from a given prefix
  * replace preprocessed file path (e.g. `/tmp/bats-run-22908-NP0f9h/bats.23102.src`)
    with original filename in stdout/err (but not FD3!)
  * print aborted command on SIGINT/CTRL+C
  * print error message when BATS_RUN_TMPDIR could not be created
* Sun Apr 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.3.0
  * Added custom test-file extension via BATS_FILE_EXTENSION when
    searching for test files in a directory
  * Added TAP13 formatter, including millisecond timing
  * Recursive suite mode will follow symlinks now
  * Split options for (file-) --report-formatter and (stdout)
  - -formatter
    WARNING: This changes the meaning of --formatter junit.
    stdout will now show unified xml instead of TAP. From now on,
    please use --report-formatter junit to obtain the .xml report file!
  * Removed --parallel-preserve-environment flag, as this is the default
  * Preprocessed files are no longer removed if --no-tempdir-cleanup
    is specified
  * Fix internal failures due to unbound variables when test files
    use set -u
  * Fix internal failures due to changes to $PATH in test files
  * Fix hangs on CTRL+C
  * Make BATS_TEST_NUMBER count per file again
  * Performance improvements
  * Improved documentation
- Dropped upstream merged
  bsc1180135-0001-fix-dont-use-unbound-variables-in-setup-methods.patch
* Thu Dec 17 2020 Aleksa Sarai <asarai@suse.com>
- Backport <https://github.com/bats-core/bats-core/pull/344>. bsc#1180135
  + bsc1180135-0001-fix-dont-use-unbound-variables-in-setup-methods.patch
* Wed Nov 18 2020 Olav Reinert <seroton10@gmail.com>
- update to 1.2.1:
  * added:
  - JUnit output and extensible formatter rewrite (#246)
  - load function now reads from absolute and relative paths, and $PATH (#282)
  - Beginner-friendly examples in /docs/examples (#243)
  - @peshay's bats-file fork contributed to bats-core/bats-file (#276)
  * changed:
  - Duplicate test names now error (previous behaviour was to issue a warning) (#286)
  - Changed default formatter in Docker to pretty by adding ncurses to Dockerfile, override with --tap (#239)
  - Replace "readlink -f" dependency with Bash solution (#217)
* Wed Nov 18 2020 Olav Reinert <seroton10@gmail.com>
- Install to /usr/libexec on Tumbleweed
* Fri Jul  3 2020 Aleksa Sarai <asarai@suse.com>
- Require gnu_parallel so that 'bats --jobs' works out of the box and is tested
  as part of the integration tests of the package.
* Wed May 20 2020 Olav Reinert <seroton10@gmail.com>
- update to 1.2.0:
  * Added:
  - docs/CHANGELOG.md and docs/releasing.md (#122)
  - The -f, --filter flag to run only the tests matching a regular expression (#126)
  - Optimize stack trace capture (#138)
  - --jobs n flag to support parallel execution of tests with GNU parallel (#172)
  * Changed:
  - AppVeyor builds are now semver-compliant (#123)
  - Add Bash 5 as test target (#181)
  - Always use upper case signal names to avoid locale dependent err… (#215)
  - Fix for tests reading from stdin (#227)
  - Fix wrong line numbers of errors in bash < 4.4 (#229)
  - Remove preprocessed source after test run (#232)
* Fri Oct 25 2019 Olav Reinert <seroton10@gmail.com>
- Reinstate prematurely removed Group tag
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Tue Jan 22 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.1.0
- drop build-term.patch  package-json.patch
- new upstream, see changes on https://github.com/bats-core/bats-core/releases
* Sat Feb 25 2017 seroton10@gmail.com
- Added build-term.patch: work-around for bnc#1026350
* Tue Feb 24 2015 seroton10@gmail.com
- Fix RPM group
* Sun Feb 22 2015 seroton10@gmail.com
- Spec file improvements:
  * Run tests in %%check section
  * Correct project URL
* Wed Feb 18 2015 seroton10@gmail.com
- Spec file improvements:
  * /usr/bin/tput is optional at runtime
  * Reference to meaning of TAP-compliant
  * Simplify launch of tests
* Mon Feb 16 2015 seroton10@gmail.com
- Initial version: bats 0.4.0
